@@ -179,7 +179,7 @@ def get_length(arg):
         total_length = len(arg.operand)
         total_length += base_length
         return total_length
-    if isinstance(arg, None):
+    if arg is None:
         return 0
     print(f"Unhandled {arg}")
     return 0
